@@ -10,7 +10,7 @@ import qtxmldom
 from qtxmldom.khtmlutils import import_doc, export_doc
 
 def main(part):
-    html_doc = qtxmldom.Node(part.document(), qtxmldom.khtmlImplementation())
+    html_doc = qtxmldom.fromNode(part.document())
     doc = import_doc(html_doc)
     query = "/h:HTML/h:BODY//h:INPUT|//h:HTML/h:BODY//h:SELECT"
     raw_fields = doc.xpath(query, namespaces={"h" : ""}) or doc.xpath(query.lower(), namespaces={"h" : "http://www.w3.org/1999/xhtml"})
