@@ -30,11 +30,73 @@ of the active document:
 
 If the module is edited, then the reload built-in function will probably update
 the code, but the active DOM objects then need to be discarded.
+
+With the KHTMLAutomation KPart active, the following can be used at a normal
+Python prompt:
+
+  doc = qtxmldom.fromRemoteObject(obj)
+
+(Where obj has been obtained using the qtxmldom.remote module - see
+examples/remote.py for more information.)
 """
 
 import xml.dom
 
-__version__ = "0.2.2"
+__version__ = "0.2.3"
+
+class RemoteNode(object):
+
+    "A representation of a remote object, accessed via DCOP."
+
+    def __init__(self, obj, accessor):
+        self.obj = obj
+        self.accessor = accessor
+
+    def __getattr__(self, name):
+        return RemoteMethod(self.obj, self.accessor, name)
+
+class RemoteMethod(object):
+
+    """
+    A wrapper around a remote method call, ensuring that the correct result is
+    obtained.
+    """
+
+    def __init__(self, obj, accessor, name):
+        import qt
+        self.qt = qt
+        self.obj = obj
+        self.accessor = accessor
+        self.name = name
+
+    def _convert_obj(self, obj):
+        if isinstance(obj, RemoteNode):
+            return obj.obj
+        else:
+            return obj
+
+    def __call__(self, *args):
+        method = getattr(self.accessor, self.name)
+
+        # Add the method's context and convert other arguments if appropriate.
+
+        args = (self.obj,) + tuple(map(self._convert_obj, args))
+
+        # Test the status.
+
+        status, result_list = method(*args)
+        if not status:
+            raise RuntimeError, "Remote method '%s' failed for node '%s'" % (self.name, self.obj)
+
+        if isinstance(result_list, self.qt.QStringList):
+            result_type = result_list[0]
+            result_value = result_list[1]
+            if result_type == "string":
+                return result_value
+            else:
+                return RemoteNode(result_value, self.accessor)
+        else:
+            return result_list
 
 class Implementation(object):
 
@@ -61,6 +123,29 @@ class Implementation(object):
                 _doctype),
             self)
 
+class khtmlRemoteImplementation(Implementation):
+
+    def __init__(self, _impl=None):
+        import qt
+        self.qt = qt
+
+    # Conversion methods.
+
+    def convert(self, _node):
+        return _node
+
+    def make_string(self, s):
+
+        # NOTE: Dubious conversion.
+
+        if s is None:
+            return self.qt.QString()
+        else:
+            return self.qt.QString(s)
+
+    def get_string(self, s):
+        return unicode(s)
+
 class khtmlImplementation(Implementation):
 
     def __init__(self, _impl=None):
@@ -541,6 +626,45 @@ class Node(object):
 
 # Convenience functions.
 
+def getRemoteDocument(remote_object):
+
+    """
+    Get a KHTML-style node for the given 'remote_object'. Use the
+    qtxmldom.remote module to find suitable objects to use with this function.
+    """
+
+    status, result = remote_object.getDocument()
+    if not status:
+        raise RuntimeError, "No remote document found for %s" % repr(remote_object)
+
+    try:
+        doc = result[1]
+        return getRemoteNode(doc, remote_object)
+    except IndexError:
+        raise RuntimeError, "No remote document found for %s" % repr(remote_object)
+
+def getRemoteNode(node, remote_object):
+
+    """
+    Get a KHTML-style node for the given 'node' accessed via the supplied
+    'remote_object'. Use the qtxmldom.remote module to find suitable objects to
+    use with this function.
+    """
+
+    return RemoteNode(node, remote_object)
+
+def fromRemoteObject(remote_object):
+
+    "Return a PyXML-style DOM for the given 'remote_object'."
+
+    return Node(getRemoteDocument(remote_object), khtmlRemoteImplementation())
+
+def fromRemoteNode(node):
+
+    "Return a PyXML-style DOM for the given remote 'node'."
+
+    return Node(node, khtmlRemoteImplementation())
+
 def fromNode(node):
 
     "Return a PyXML-style DOM for the given KHTML 'node'."
